@@ -12,6 +12,7 @@
 #endif	/* MAILER */
 #include <ctype.h>
 #include <sys/file.h>
+#include <sys/stat.h>
 #include <fcntl.h>
 
 #include "mailer.h"
@@ -100,7 +101,8 @@ STATIC status_t reapstatus;		/* status of last reaped process */
  */
 
 STATIC void
-reapchild()
+reapchild(sig)
+int sig;
 {
 	status_t status;
 	register int i, pid;
