@@ -190,7 +190,7 @@ makeLetter(e, octothorp)
 	e->e_headers = 0;
 	e->e_hdrOffset = 0;
 	e->e_msgOffset = 0;
-	e->e_nowtime = now = time((long *)0);
+	e->e_nowtime = now = time(NULL);
 	if (efstat(fileno(e->e_fp), &(e->e_statbuf)) < 0) {
 #ifdef	USE_STATBLKSIZE
 		e->e_statbuf.st_blksize = 0;
@@ -224,7 +224,8 @@ makeLetter(e, octothorp)
 			if (inheader && linebuf[0] == ':') {
 				optsave(FYI_ILLHEADER, e);
 				/* cons up a new one at top of header list */
-				h = makeHeader(spt_headers, "X-Null-Field", 12);
+				h = makeHeader(spt_headers,
+					       (u_char*)"X-Null-Field", 12);
 				h->h_next = e->e_headers;
 				e->e_headers = h;
 				h->h_lines = makeToken(linebuf+i+1, n-i-2);
@@ -427,7 +428,7 @@ int	isRecpntAddr = 0;
 	} }
 
 /* Make it possible to do real override of Errors-To: with  $(listaddress ...) */
-u_char *errors_to = NULL;
+char *errors_to = NULL;
 
 
 
@@ -1093,7 +1094,7 @@ sequencer(e, file)
 	envid = NULL;
 	if (h != NULL && h->h_contents.a != NULL
 	    && h->h_contents.a->a_pname != NULL) {
-		envid = h->h_contents.a->a_pname;
+		envid = (char*)h->h_contents.a->a_pname;
 	}
 	FindEnvelope(eFrom);
 	if (h == NULL) {
@@ -1427,7 +1428,7 @@ sequencer(e, file)
 			}
 			DSN = (struct notary *)tmalloc(sizeof(struct notary));
 			DSN->envid = envid;
-			DSN->dsn = h->h_contents.a->a_pname;
+			DSN->dsn = (char*)h->h_contents.a->a_pname;
 			continue;
 		}
 		if (DSN != NULL) {
@@ -1619,7 +1620,7 @@ sequencer(e, file)
 	 */
 
 	if (!iserrmessage()) {
-#if 0
+#if 1
                 if (errors_to != NULL) {        /* [mea@utu.fi] Stupid, but workable.. */
                         putc(_CF_ERRORADDR, ofp);
                         putc(_CFTAG_NORMAL, ofp);
