@@ -375,8 +375,17 @@ spool(thread)
 	     * by the fifo rescheduling functions below.
 	     */
 	    fifoput(vp);
-	  } else
+	  } else {
+	    /*
+	     * Mark the thread-entry eligible for processing in
+	     * the transport.c:transport()
+	     *   (Anything goes, as long as it is  != V_NONE)
+	     */
 	    vp->cfp->mark = V_SELECT;
+if (verbose && vp->cfp->atspool != NULL)
+  printf("spool(): vp->cfp->atspool != NULL !\n");
+	    vp->cfp->atspool = vp;
+	  }
 	}
 	transport(thread, thread->orig[L_CHANNEL]->name,
 			  thread->orig[L_HOST]->name);
