@@ -74,7 +74,7 @@ main(argc, argv)
 	struct passwd *pw;
 #ifdef	AF_INET
 	short port = 0;
-	u_long naddr;
+	struct in_addr naddr;
 	char *host = NULL;
 	struct hostent *hp, he;
 	struct sockaddr_in sad;
@@ -212,9 +212,9 @@ main(argc, argv)
 	    }
 	  }
 	  if ((hp = gethostbyname(host)) == NULL) {
-	    if ((naddr = inet_addr(host)) != (u_long)-1) {
-	      naddr = ntohl(naddr);
-	      if ((hp = gethostbyaddr(&naddr, 4, AF_INET)) == NULL) {
+	    if ((naddr.s_addr = inet_addr(host)) != -1) {
+	      naddr.s_addr = ntohl(naddr.s_addr);
+	      if ((hp = gethostbyaddr((void*)&naddr, sizeof(naddr), AF_INET)) == NULL) {
 		hp = &he;
 		he.h_name = host;
 		he.h_length = 4;
@@ -246,7 +246,7 @@ main(argc, argv)
 	}
 	sad.sin_family = AF_INET;
 	if (hp == &he)
-	  sad.sin_addr.s_addr = htonl(naddr);
+	  sad.sin_addr.s_addr = htonl(naddr.s_addr);
 	else {
 	  char *addr;
 
@@ -255,14 +255,14 @@ main(argc, argv)
 	  while ((addr = *hp_getaddr()) != NULL) {
 	    sad.sin_addr.s_addr = 0;
 	    sad.sin_port = htons((short)0);
-	    if (bind(fd, (caddr_t)&sad, sizeof sad) < 0) {
+	    if (bind(fd, (void*)&sad, sizeof sad) < 0) {
 	      fprintf(stderr, "%s: ", progname);
 	      perror("bind");
 	      exit(EX_UNAVAILABLE);
 	    }
 	    sad.sin_port = port;
-	    memcpy((char *)&sad.sin_addr, addr, hp->h_length);
-	    if (connect(fd, (char *)&sad, sizeof sad) < 0) {
+	    memcpy((void*)&sad.sin_addr, addr, hp->h_length);
+	    if (connect(fd, (void*)&sad, sizeof sad) < 0) {
 	      eval = errno;
 	      fprintf(stderr,
 		      "%s: connect failed to %s",
