@@ -117,7 +117,7 @@ extern void queryipcinit __((void));
 extern void reschedule __((struct vertex *vp, int factor, int index));
 extern int  syncweb __((char *dir, int nukefile, struct config_entry *ce));
 extern void unctlfile __((struct ctlfile *cfp));
-extern void vtxdo __((struct vertex *vp, struct config_entry *ce));
+extern void vtxdo __((struct vertex *vp, struct config_entry *ce, char *path));
 extern void vtxprint __((struct vertex *vp));
 extern void defaultconfigentry __((struct config_entry *ce, struct config_entry *));
 
@@ -220,7 +220,7 @@ main(argc, argv)
 		if (loginit(SIGHUP) < 0)	/* do setlinebuf() there */
 			die(1, "log initialization failure");
 		/* close and reopen log files */
-		SIGNAL_HANDLE(SIGHUP, loginit);
+		SIGNAL_HANDLE(SIGHUP, (SIGNAL_TYPE(*)())loginit);
 	} else {
 		SIGNAL_IGNORE(SIGHUP); /* no surprises please */
 		setvbuf(stdout, (char *)NULL, _IOLBF, 0);
@@ -229,8 +229,10 @@ main(argc, argv)
 #ifdef USE_SIGREAPER
 #ifdef SIGCLD
 	SIGNAL_HANDLE(SIGCLD,  sig_chld);
+	/* SIGNAL_HANDLE(SIGCLD,SIG_IGN);	/* Auto-reap the kids.. */
 #else
 	SIGNAL_HANDLE(SIGCHLD, sig_chld);
+	/* SIGNAL_HANDLE(SIGCHLD,SIG_IGN); */
 #endif
 #endif
 
@@ -493,11 +495,16 @@ syncweb(dir, nukefile, cehead)
 	      }
 	      schedule(fd, file, cehead);
 	      ++wrkcnt;
-	      if (nukefile)
+	      if (nukefile) {
 		unlink(file);
-	      else		/* we're scanning TRANSPORTDIR */
+		if (verbose)
+		  printf("scheduler: completed %s\n",file);
+	      } else {		/* we're scanning TRANSPORTDIR */
 		/* unlink it from the SCHEDULERDIR */
 		unlink(dp->d_name);
+		if (verbose)
+		  printf("scheduler: completed %s\n",dp->d_name);
+	      }
 	      /*
 	       * This avoids a race when the
 	       * scheduler starts up while the router
@@ -543,8 +550,11 @@ schedule(fd, file, cehead)
 
 	/* read and process the control file */
 	if ((cfp = vtxprep(slurp(fd))) == NULL) {
-	  if (!vtxprep_skip)	/* Unless skipped.. */
+	  if (!vtxprep_skip) {	/* Unless skipped.. */
 	    eunlink(file);	/* everything here has been processed */
+	    if (verbose)
+	      printf("completed, unlink %s\n",file);
+	  }
 	  vtxprep_skip_any |= vtxprep_skip;
 	  return NULL;
 	}
@@ -553,7 +563,6 @@ schedule(fd, file, cehead)
 	  return NULL;
 	}
 	/* -- DO NOT FREE CFP->CONTENTS YET! 
-
 	   if (cfp->contents != NULL && cfp->vfp == NULL) {
 	   free(cfp->contents);
 	   cfp->contents = NULL;
@@ -568,6 +577,7 @@ schedule(fd, file, cehead)
 	    dir = vp->orig[L_CHANNEL]->name; /* channel/file */
 	  } else
 	    dir = NULL;
+	  *path = 0;
 	  if (dir != NULL) {
 	    sprintf(path, "%s/%lu", dir, cfp->id);
 	    mklink(file, path);
@@ -578,7 +588,7 @@ schedule(fd, file, cehead)
 		     vp->cfp->mid, vp->cfp->id, path);
 	  }
 
-	  vtxdo(vp, cehead);
+	  vtxdo(vp, cehead, path);
 	  if (cfp->vfp)
 	    fseek(cfp->vfp, 0, 2);
 	}
@@ -619,6 +629,8 @@ slurp(fd)
 
 	cfp->fd = fd;
 	cfp->vfp = NULL;
+	cfp->head = NULL;
+	cfp->atspool = NULL;
 	cfp->uid = stbuf.st_uid;
 	cfp->mark = V_NONE;
 	cfp->haderror = 0;
@@ -1002,6 +1014,8 @@ vtxprep(cfp)
 	      vp = (struct vertex *)emalloc(alloc_size);
 	      memset((char*)vp, 0, alloc_size);
 	      vp->cfp = cfp;
+	      vp->linkcnt  = 0;
+	      vp->linkpath = NULL;
 	      defaultconfigentry(&vp->ce,NULL);
 	      vp->next[L_CTLFILE] = NULL;
 	      vp->prev[L_CTLFILE] = pvp;
@@ -1044,6 +1058,8 @@ vtxprep(cfp)
 	  vp = (struct vertex *)emalloc(alloc_size);
 	  memset((void*)vp, 0, alloc_size);
 	  vp->cfp = cfp;
+	  vp->linkcnt  = 0;
+	  vp->linkpath = NULL;
 	  defaultconfigentry(&vp->ce,NULL);
 	  vp->next[L_CTLFILE] = NULL;
 	  vp->prev[L_CTLFILE] = pvp;
@@ -1131,9 +1147,10 @@ vtxfill(vp, tp)
 }
 
 void
-vtxdo(vp, cehead)
+vtxdo(vp, cehead, path)
 	struct vertex *vp;
 	struct config_entry *cehead;
+	char *path;
 {
 	struct config_entry *tp;
 	int n;
@@ -1184,6 +1201,9 @@ vtxdo(vp, cehead)
 	if (verbose>1)
 	  vtxprint(vp);
 
+	if (vp->linkpath != NULL)
+	  free(vp->linkpath);
+	vp->linkpath = strsave(path);
 	if ((vp->ce.flags & FF_GANGSCHEDULE)
 	    && vp->prev[L_HOST] != NULL
 	    && vp->prev[L_CHANNEL] != NULL
