@@ -60,7 +60,7 @@ extern void update();
  * of that command.
  */
 
-static int t_n;
+static int t_n, t_nmax;
 static char **t_files;
 
 int
@@ -68,24 +68,53 @@ tscan(spl)
 	struct spblk *spl;
 {
 	struct ctlfile *cfp = (struct ctlfile *)spl->data;
+#if 0
 	char *dir, path[MAXPATHLEN], buf[MAXPATHLEN];
+#endif
 
 	/* assert cfp != NULL */
-	if (cfp->mark == V_NONE || t_n >= MAXFILESPERTRANSPORT)
+
+	/* Is this marked ? */
+	if (cfp->mark == V_NONE)
+	  return -1; /* .. No. */
+
+	/* If the count of jobs exceeds our high guesses.. */
+	if (t_n >= t_nmax) {
+	  /* Report only once per scan.. */
+	  if (t_nmax > 0)
+	    printf("**AARGH**  MAXFILESPERTRANSPORT(%d) TURNED OUT TO BE TOO SMALL!\n", t_nmax);
+	  t_nmax = 0;
+	  /* Clear the markings.. */
+	  cfp->mark    = V_NONE;
+	  cfp->atspool = NULL;
 	  return -1;
+	}
+#if 0
 	/*
 	 * XX: Note that any old filename will do for the control file,
 	 * since all names are links to the same file anyway.
 	 * However, we need to get the filename right, based on
 	 * our favorite filename generation technique.
+	 *
+	 * XX: Wrong, not just ANY, it MUST match the thing each
+	 *     transporter expects!  Thus when all hosts become
+	 *     processed, the links can be released.
+	 *
+	 * Solution: We use  cfp->atspool/*vertex*/->linkpath  for it!
 	 */
+
 	if (subsubdirs)	/* channel/host */
-	  dir = vtx_to_dir(cfp->head, buf);
+	  dir = vtx_to_dir(cfp->atspool, buf);
 	else		/* channel */
-	  dir = cfp->head->orig[L_CHANNEL]->name;
+	  dir = cfp->atspool->orig[L_CHANNEL]->name;
 	sprintf(path, "%s/%lu", dir, cfp->id);
-	t_files[t_n++] = strsave(path);
-	cfp->mark = V_NONE;
+
+	if (verbose)
+	  printf("  tscan() path=\"%s\"\n",path);
+#endif
+	t_files[t_n++] = cfp->atspool->linkpath;
+	cfp->mark    = V_NONE;
+	cfp->atspool = NULL;
 	return 0;
 }
 
@@ -98,12 +127,21 @@ transport(vhead, channel, host)
 	char *files[MAXFILESPERTRANSPORT];	/* XX */
 
 	/* generate the file names we care about */
-	t_n = 0;
+	t_n     = 0;
+	t_nmax  = MAXFILESPERTRANSPORT;
 	t_files = files;
+
+	if (verbose)
+	  printf("transport(vhead,chan=\"%s\",host=\"%s\")\n",channel,host);
+
 	sp_scan(tscan, (struct spblk *)NULL, spt_mesh[L_CTLFILE]);
 	dotransport(files, t_n, vhead, channel, host);
+
+#if 0
+	/* Free the strings malloced on  tscan() */
 	for (i = 0; i < t_n; ++i)
-		free(files[i]);
+	  free(files[i]);
+#endif
 }
 
 void
@@ -882,7 +920,18 @@ int signum;
 #else
 	int statloc;
 #endif
+#ifdef USE_UNIONWAIT
+	while ((pid = wait3(&statloc,WNOHANG,NULL)) > 0) ;
+#else
+#ifdef	USE_WAITPID
+	while ((pid = waitpid(-1,&statloc,WNOHANG)) > 0) ;
+#else
 	pid = wait(&statloc);
+#endif
+#endif
+
+
+#if 0	/* DO NOT do anything excessive -- we don't care WHO died.. */
 
 #ifdef	WIFEXITED
 	if (WIFEXITED(statloc)) ok = 1;
@@ -914,9 +963,8 @@ printf(" .. already reaped ??\n");
 	      break;
 	    }
 	  }
-	  if (ok)
-	    --numkids; /* A non-transporter-child (mailq() ?) */
 	}
+#endif
 	/* re-instantiate the signal handler.. */
 #ifdef SIGCLD
 	SIGNAL_HANDLE(SIGCLD,  sig_chld);
