@@ -145,9 +145,14 @@ unctlfile(cfp)
 #endif	/* LOG_INFO */
 	sprintf(path, "../%s/%s", TRANSPORTDIR, cfp->mid);
 	eunlink(path);
-/* printf("%s: unlink %s\n", cfp->logident, path); */
+if (verbose)
+  printf("%s: unlink %s", cfp->logident, path);
+
 	sprintf(path, "../%s/%s", QUEUEDIR, cfp->mid);
 	eunlink(path);
+if (verbose)
+  printf("   and %s/\n", path);
+
 	if (cfp->vfp != NULL) {
 	  fseek(cfp->vfp, 0, 2);
 	  fprintf(cfp->vfp,
@@ -182,6 +187,9 @@ unvertex(vp)
 		  vp->orig[L_HOST]->name,
 		  vp->cfp->id);
 	  eunlink(path);
+if (verbose)
+  printf("%s: unlink %s\n", vp->cfp->logident, path);
+
 	  if (vp->cfp->vfp != NULL) {
 	    fseek(vp->cfp->vfp, 0, 2);
 	    fprintf(vp->cfp->vfp, "unlinked %s\n", path);
@@ -224,6 +232,9 @@ unvertex(vp)
 		    vp->orig[L_CHANNEL]->name,
 		    vp->cfp->id);
 	    eunlink(path);
+if (verbose)
+  printf("%s: unlink %s\n", vp->cfp->logident, path);
+
 	    if (vp->cfp->vfp != NULL) {
 	      fseek(vp->cfp->vfp, 0, 2);
 	      fprintf(vp->cfp->vfp, "unlinked %s\n", path);
