@@ -605,7 +605,7 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 	  while ((i = read(mfd, let_buffer, sizeof let_buffer)) != 0) {
 #else
 	    char *let_buffer = dp->let_buffer + dp->msgbodyoffset;
-	    i = dp->let_end - dp->let_buffer - dp->msgbodyoffset;
+	    i = dp->let_end - (dp->let_buffer + dp->msgbodyoffset);
 #endif
 	    if (i < 0)
 	      return EX_IOERR;
